@@ -69,7 +69,6 @@ def LoadPresetNames():
 
     for i in range(0, 4):
         try:
-            print i
             tmp=PresetNames.get('main', 'preset'+str(i+1))
             data.preset_names[i] = tmp.decode("utf-8")
         except:
@@ -86,7 +85,7 @@ def WritePresetNames():
     global PresetNames
     print "Write preset names"
 
-    for i in range(0, 3):
+    for i in range(0, 4):
         if(data.preset_names[i]!=""): name=str(data.preset_names[i].encode( "utf-8" ))
         else: name=""
         PresetNames.set('main', 'Preset'+str(i+1),  name)
@@ -188,20 +187,15 @@ def LoadConfig():
 
 
 ## Add forced configuration changes here
-    configFileVersion = Config_Load_Int('main', 'configFileVersion', 0)
-    if(configFileVersion<data.configFileVersion): #config file is old, update some parameters...
-        if(data.configFileVersion<=3):
+    data.configFileVersion_old = Config_Load_Int('main', 'configFileVersion', 0)
+    if(data.configFileVersion_old<data.configFileVersion): #config file is old, update some parameters...
+        if(data.configFileVersion_old<=3): #adjust scaling
             data.Yscale_Movement=data.Yscale_Movement_default
             config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
 
-        QMessageBox.critical(None, "Changes in SleepAnalyser",
-        "There are many new functions and changes in SleepAnalyser. " + \
-        "Please have a look in the help menu to see what has changed. " + \
-        "Because of the changes some parameters might need readjustment. " + \
-        "You can change them in the configuration menu.")
-
     else: #config file up to date
         pass
+        
 
     print "Configuration successful loaded from "+data.ConfigFile
 #    PrintConfig() ##debug only
