@@ -29,6 +29,9 @@ def install_excepthook(app_name,app_version):
 
     def my_excepthook(exctype, value, tb):
 
+        print "--> THE ERROR OCCURED HERE <--\n"
+        print "-----------------------------------------------------------------------------"
+
         delete_all_Alarms()
 
         #traceback give us all the errors information message like the method, file line ... everything like
